@@ -7,7 +7,7 @@
 #'@param horizon Time horizon for impulse response functions
 #'@param nboot Number of bootstrap iterations
 #'@param nc Number of processor cores (Not available on windows machines)
-#'@param dd Object of class 'indepTestDist'. A simulated independent sample of the same size as the data. If not supplied, it will be culculated by the function
+#'@param dd Object of class 'indepTestDist'. A simulated independent sample of the same size as the data. If not supplied, it will be calculated by the function
 #'@param itermax Maximum number of iterations for DEoptim
 #'@param steptol Tolerance for steps without improvement for DEoptim
 #'@param iter2 Number of iterations for the second optimization
@@ -101,20 +101,31 @@ wild.boot <- function(x, rademacher = FALSE, horizon, nboot, nc = 1, dd = NULL,
   errors <- list()
   for(i in 1:nboot){
     ub <- u
-    my <- rnorm(n = ncol(y))
+    my <- rnorm(n = ncol(u))
+    #my <- rnorm(1)
     if (rademacher == TRUE) {
       my <- (my > 0) - (my < 0)
     }
-    errors[[i]] <- ub * my
+    errors[[i]] <- ub* my
   }
 
   # Bootstrapfunction
   bootf <- function(Ustar1){
 
     Ystar <- t(A %*% Z + Ustar1)
-    varb <- VAR(Ystar, p = p)
 
-    Sigma_u_star <- crossprod(residuals(varb))/(ncol(Ustar1) - 1 - k * p)
+    Bstar <- t(Ystar) %*% t(Z) %*% solve(Z %*% t(Z))
+
+    Ustar <- t(y[-c(1:p),]) - Bstar %*% Z
+
+    Sigma_u_star <- tcrossprod(Ustar)/(ncol(Ustar1) - 1 - k * p)
+
+    varb <- list(y = y,
+                 coef_x = Bstar,
+                 residuals = t(Ustar),
+                 p = p,
+                 type = x$type)
+    class(varb) <- 'var.boot'
 
     if(x$method == "Non-Gaussian maximum likelihood"){
       temp <- id.ngml(varb, stage3 = x$stage3)
@@ -128,13 +139,13 @@ wild.boot <- function(x, rademacher = FALSE, horizon, nboot, nc = 1, dd = NULL,
 
     Pstar <- temp$B
 
-    Pstar1 <- sqrt.f(Pstar, Sigma_u_star)
-    diag_sigma_root <- diag(diag(suppressMessages(expm(B))))
+     Pstar1 <- sqrt.f(Pstar, Sigma_u_star)
+     diag_sigma_root <- diag(diag(suppressMessages(sqrtm(Sigma_u_hat_old))))
 
-    frobP <- frobICA_mod(t(solve(diag_sigma_root)%*%Pstar1), t(solve(diag_sigma_root)%*%B), standardize=TRUE)
-    Pstar <- Pstar1%*%frobP$perm
+     frobP <- frobICA_mod(t(solve(diag_sigma_root)%*%Pstar1), t(solve(diag_sigma_root)%*%B), standardize=TRUE)
+     Pstar <- Pstar1%*%frobP$perm
 
-    temp$B <- Pstar
+     temp$B <- Pstar
 
     ip <- imrf(temp, horizon = horizon)
     return(list(ip, Pstar))
